pub fn load() -> CacheConfigExpand description
Loads the current environment’s CacheConfig, falling back to the default
(in-memory) when the file is missing or has no cache section.
pub fn load() -> CacheConfigLoads the current environment’s CacheConfig, falling back to the default
(in-memory) when the file is missing or has no cache section.