pub fn set_store(store: Arc<dyn CacheStore>) -> Result<(), Arc<dyn CacheStore>>Expand description
Installs an already-built store as the global default (e.g. in tests).
Returns Err with the store back if one was already installed.
pub fn set_store(store: Arc<dyn CacheStore>) -> Result<(), Arc<dyn CacheStore>>Installs an already-built store as the global default (e.g. in tests).
Returns Err with the store back if one was already installed.